@@ -33,7 +33,7 @@ from gns3server.utils.asyncio.telnet_server import AsyncioTelnetServer
 from gns3server.utils.asyncio.raw_command_server import AsyncioRawCommandServer
 from gns3server.utils.asyncio import wait_for_file_creation
 from gns3server.utils.asyncio import monitor_process
-from gns3server.utils.get_resource import get_resource
+from gns3server.utils import macaddress_to_int, int_to_macaddress
 
 from gns3server.ubridge.ubridge_error import UbridgeError, UbridgeNamespaceError
 from ..base_node import BaseNode
@@ -83,9 +83,9 @@ class DockerVM(BaseNode):
         self._environment = environment
         self._cid = None
         self._ethernet_adapters = []
+        self._mac_address = ""
         self._temporary_directory = None
         self._telnet_servers = []
-        self._xvfb_process = None
         self._vnc_process = None
         self._vncconfig_process = None
         self._console_resolution = console_resolution
@@ -107,6 +107,8 @@ class DockerVM(BaseNode):
         else:
             self.adapters = adapters
 
+        self.mac_address = ""  # this will generate a MAC address
+
         log.debug("{module}: {name} [{image}] initialized.".format(module=self.manager.module_name,
                                                                    name=self.name,
                                                                    image=self._image))
@@ -120,6 +122,7 @@ class DockerVM(BaseNode):
             "project_id": self._project.id,
             "image": self._image,
             "adapters": self.adapters,
+            "mac_address": self.mac_address,
             "console": self.console,
             "console_type": self.console_type,
             "console_resolution": self.console_resolution,
@@ -150,6 +153,36 @@ class DockerVM(BaseNode):
     def ethernet_adapters(self):
         return self._ethernet_adapters
 
+    @property
+    def mac_address(self):
+        """
+        Returns the MAC address for this Docker container.
+
+        :returns: adapter type (string)
+        """
+
+        return self._mac_address
+
+    @mac_address.setter
+    def mac_address(self, mac_address):
+        """
+        Sets the MAC address for this Docker container.
+
+        :param mac_address: MAC address
+        """
+
+        if not mac_address:
+            # use the node UUID to generate a random MAC address
+            self._mac_address = "02:42:%s:%s:%s:00" % (self.id[2:4], self.id[4:6], self.id[6:8])
+        else:
+            self._mac_address = mac_address
+
+        log.info('Docker container "{name}" [{id}]: MAC address changed to {mac_addr}'.format(
+            name=self._name,
+            id=self._id,
+            mac_addr=self._mac_address)
+        )
+
     @property
     def start_command(self):
         return self._start_command
@@ -243,10 +276,13 @@ class DockerVM(BaseNode):
         :returns: Return the path that we need to map to local folders
         """
 
-        resources = get_resource("compute/docker/resources")
-        if not os.path.exists(resources):
-            raise DockerError("{} is missing can't start Docker containers".format(resources))
-        binds = ["{}:/gns3:ro".format(resources)]
+        try:
+            resources_path = self.manager.resources_path()
+        except OSError as e:
+            raise DockerError(f"Cannot access resources: {e}")
+
+        log.info(f'Mount resources from "{resources_path}"')
+        binds = ["{}:/gns3:ro".format(resources_path)]
 
         # We mount our own etc/network
         try:
@@ -323,6 +359,9 @@ class DockerVM(BaseNode):
         Creates the Docker container.
         """
 
+        if ":" in os.path.splitdrive(self.working_dir)[1]:
+            raise DockerError("Cannot create a Docker container with a project directory containing a colon character (':')")
+
         try:
             image_infos = await self._get_image_information()
         except DockerHttp404Error:
@@ -344,6 +383,7 @@ class DockerVM(BaseNode):
                 "CapAdd": ["ALL"],
                 "Privileged": True,
                 "Binds": self._mount_binds(image_infos),
+                "UsernsMode": "host",
             },
             "Volumes": {},
             "Env": ["container=docker"],  # Systemd compliant: https://github.com/GNS3/gns3-server/issues/573
@@ -404,7 +444,7 @@ class DockerVM(BaseNode):
             await self._start_vnc()
             params["Env"].append("QT_GRAPHICSSYSTEM=native")  # To fix a Qt issue: https://github.com/GNS3/gns3-server/issues/556
             params["Env"].append("DISPLAY=:{}".format(self._display))
-            params["HostConfig"]["Binds"].append("/tmp/.X11-unix/:/tmp/.X11-unix/")
+            params["HostConfig"]["Binds"].append("/tmp/.X11-unix/X{0}:/tmp/.X11-unix/X{0}:ro".format(self._display))
 
         if self._extra_hosts:
             extra_hosts = self._format_extra_hosts(self._extra_hosts)
@@ -458,6 +498,8 @@ class DockerVM(BaseNode):
         Starts this Docker container.
         """
 
+        await self.manager.install_resources()
+
         try:
             state = await self._get_container_state()
         except DockerHttp404Error:
@@ -474,6 +516,9 @@ class DockerVM(BaseNode):
                 await self._start_vnc_process(restart=True)
                 monitor_process(self._vnc_process, self._vnc_callback)
 
+            if self._console_websocket:
+                await self._console_websocket.close()
+                self._console_websocket = None
             await self._clean_servers()
 
             await self.manager.query("POST", "containers/{}/start".format(self._cid))
@@ -582,8 +627,8 @@ class DockerVM(BaseNode):
         self._display = self._get_free_display_port()
         tigervnc_path = shutil.which("Xtigervnc") or shutil.which("Xvnc")
 
-        if not (tigervnc_path or shutil.which("Xvfb") and shutil.which("x11vnc")):
-            raise DockerError("Please install TigerVNC (recommended) or Xvfb + x11vnc before using VNC support")
+        if not tigervnc_path:
+            raise DockerError("Please install TigerVNC server before using VNC support")
 
         if tigervnc_path:
             with open(os.path.join(self.working_dir, "vnc.log"), "w") as fd:
@@ -597,29 +642,6 @@ class DockerVM(BaseNode):
                                                                          "-SecurityTypes", "None",
                                                                          ":{}".format(self._display),
                                                                          stdout=fd, stderr=subprocess.STDOUT)
-        else:
-            if restart is False:
-                self._xvfb_process = await asyncio.create_subprocess_exec("Xvfb",
-                                                                          "-nolisten", "tcp",
-                                                                          "-extension", "MIT-SHM",
-                                                                          ":{}".format(self._display),
-                                                                          "-screen", "0",
-                                                                          self._console_resolution + "x16")
-
-            # We pass a port for TCPV6 due to a crash in X11VNC if not here: https://github.com/GNS3/gns3-server/issues/569
-            with open(os.path.join(self.working_dir, "vnc.log"), "w") as fd:
-                self._vnc_process = await asyncio.create_subprocess_exec("x11vnc",
-                                                                         "-forever",
-                                                                         "-nopw",
-                                                                         "-shared",
-                                                                         "-noshm",
-                                                                         "-geometry", self._console_resolution,
-                                                                         "-display", "WAIT:{}".format(self._display),
-                                                                         "-rfbport", str(self.console),
-                                                                         "-rfbportv6", str(self.console),
-                                                                         "-noncache",
-                                                                         "-listen", self._manager.port_manager.console_host,
-                                                                         stdout=fd, stderr=subprocess.STDOUT)
 
     async def _start_vnc(self):
         """
@@ -628,8 +650,8 @@ class DockerVM(BaseNode):
 
         self._display = self._get_free_display_port()
         tigervnc_path = shutil.which("Xtigervnc") or shutil.which("Xvnc")
-        if not (tigervnc_path or shutil.which("Xvfb") and shutil.which("x11vnc")):
-            raise DockerError("Please install TigerVNC server (recommended) or Xvfb + x11vnc before using VNC support")
+        if not tigervnc_path:
+            raise DockerError("Please install TigerVNC server before using VNC support")
         await self._start_vnc_process()
         x11_socket = os.path.join("/tmp/.X11-unix/", "X{}".format(self._display))
         try:
@@ -688,7 +710,10 @@ class DockerVM(BaseNode):
         """
 
         # resize the container TTY.
-        await self._manager.query("POST", "containers/{}/resize?h={}&w={}".format(self._cid, rows, columns))
+        try:
+            await self._manager.query("POST", "containers/{}/resize?h={}&w={}".format(self._cid, rows, columns))
+        except DockerError as e:
+            log.warning(f"Could not resize the container TTY: {e}")
 
     async def _start_console(self):
         """
@@ -718,9 +743,7 @@ class DockerVM(BaseNode):
 
         self._console_websocket = await self.manager.websocket_query("containers/{}/attach/ws?stream=1&stdin=1&stdout=1&stderr=1".format(self._cid))
         input_stream.ws = self._console_websocket
-
         output_stream.feed_data(self.name.encode() + b" console is now available... Press RETURN to get started.\r\n")
-
         asyncio.ensure_future(self._read_console_output(self._console_websocket, output_stream))
 
     async def _read_console_output(self, ws, out):
@@ -743,13 +766,14 @@ class DockerVM(BaseNode):
                 out.feed_eof()
                 await ws.close()
                 break
-        await self.stop()
 
     async def reset_console(self):
         """
         Reset the console.
         """
 
+        if self._console_websocket:
+            await self._console_websocket.close()
         await self._clean_servers()
         await self._start_console()
 
@@ -794,6 +818,9 @@ class DockerVM(BaseNode):
         """
 
         try:
+            if self._console_websocket:
+                await self._console_websocket.close()
+                self._console_websocket = None
             await self._clean_servers()
             await self._stop_ubridge()
 
@@ -872,12 +899,6 @@ class DockerVM(BaseNode):
                         await self._vnc_process.wait()
                     except ProcessLookupError:
                         pass
-                if self._xvfb_process:
-                    try:
-                        self._xvfb_process.terminate()
-                        await self._xvfb_process.wait()
-                    except ProcessLookupError:
-                        pass
 
                 if self._display:
                     display = "/tmp/.X11-unix/X{}".format(self._display)
@@ -931,15 +952,33 @@ class DockerVM(BaseNode):
         bridge_name = 'bridge{}'.format(adapter_number)
         await self._ubridge_send('bridge create {}'.format(bridge_name))
         self._bridges.add(bridge_name)
-        await self._ubridge_send('bridge add_nio_tap bridge{adapter_number} {hostif}'.format(adapter_number=adapter_number,
-                                                                                                  hostif=adapter.host_ifc))
+        await self._ubridge_send('bridge add_nio_tap bridge{adapter_number} {hostif}'.format(
+            adapter_number=adapter_number,
+            hostif=adapter.host_ifc)
+        )
+
+        mac_address = int_to_macaddress(macaddress_to_int(self._mac_address) + adapter_number)
+        custom_adapter = self._get_custom_adapter_settings(adapter_number)
+        custom_mac_address = custom_adapter.get("mac_address")
+        if custom_mac_address:
+            mac_address = custom_mac_address
+
+        try:
+            await self._ubridge_send('docker set_mac_addr {ifc} {mac}'.format(ifc=adapter.host_ifc, mac=mac_address))
+        except UbridgeError:
+            log.warning("Could not set MAC address %s on interface %s", mac_address, adapter.host_ifc)
+
         log.debug("Move container %s adapter %s to namespace %s", self.name, adapter.host_ifc, self._namespace)
         try:
-            await self._ubridge_send('docker move_to_ns {ifc} {ns} eth{adapter}'.format(ifc=adapter.host_ifc,
-                                                                                             ns=self._namespace,
-                                                                                             adapter=adapter_number))
+            await self._ubridge_send('docker move_to_ns {ifc} {ns} eth{adapter}'.format(
+                ifc=adapter.host_ifc,
+                ns=self._namespace,
+                adapter=adapter_number)
+            )
         except UbridgeError as e:
             raise UbridgeNamespaceError(e)
+        else:
+            log.info("Created adapter %s with MAC address %s in namespace %s", adapter_number, mac_address, self._namespace)
 
         if nio:
             await self._connect_nio(adapter_number, nio)
