@@ -15,13 +15,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import sys
 import os
 import json
 import uuid
 import asyncio
 import aiohttp
 import shutil
+import platformdirs
+
 
 try:
     import importlib_resources
@@ -81,15 +82,15 @@ class ApplianceManager:
         os.makedirs(appliances_path, exist_ok=True)
         return appliances_path
 
-    def _builtin_appliances_path(self, delete_first=False):
+    def builtin_appliances_path(self):
         """
         Get the built-in appliance storage directory
         """
 
-        config = Config.instance()
-        appliances_dir = os.path.join(config.config_dir, "appliances")
-        if delete_first:
-            shutil.rmtree(appliances_dir, ignore_errors=True)
+        server_config = Config.instance().get_section_config("Server")
+        appname = vendor = "GNS3"
+        resources_path = os.path.expanduser(server_config.get("resources_path", platformdirs.user_data_dir(appname, vendor, roaming=True)))
+        appliances_dir = os.path.join(resources_path, "appliances")
         os.makedirs(appliances_dir, exist_ok=True)
         return appliances_dir
 
@@ -98,19 +99,11 @@ class ApplianceManager:
         At startup we copy the built-in appliances files.
         """
 
-        dst_path = self._builtin_appliances_path(delete_first=True)
+        dst_path = self.builtin_appliances_path()
         log.info(f"Installing built-in appliances in '{dst_path}'")
+        from . import Controller
         try:
-            if hasattr(sys, "frozen") and sys.platform.startswith("win"):
-                resource_path = os.path.normpath(os.path.join(os.path.dirname(sys.executable), "appliances"))
-                for filename in os.listdir(resource_path):
-                    shutil.copy(os.path.join(resource_path, filename), os.path.join(dst_path, filename))
-            else:
-                for entry in importlib_resources.files('gns3server.appliances').iterdir():
-                    full_path = os.path.join(dst_path, entry.name)
-                    if entry.is_file():
-                        log.debug(f"Installing built-in appliance file {entry.name} to {full_path}")
-                        shutil.copy(str(entry), os.path.join(dst_path, entry.name))
+            Controller.instance().install_resource_files(dst_path, "appliances")
         except OSError as e:
             log.error(f"Could not install built-in appliance files to {dst_path}: {e}")
 
@@ -120,7 +113,7 @@ class ApplianceManager:
         """
 
         self._appliances = {}
-        for directory, builtin in ((self._builtin_appliances_path(), True,), (self._custom_appliances_path(), False,)):
+        for directory, builtin in ((self.builtin_appliances_path(), True,), (self._custom_appliances_path(), False,)):
             if directory and os.path.isdir(directory):
                 for file in os.listdir(directory):
                     if not file.endswith('.gns3a') and not file.endswith('.gns3appliance'):
@@ -208,7 +201,10 @@ class ApplianceManager:
                 log.info("Checking if appliances are up-to-date (ETag {})".format(self._appliances_etag))
                 headers["If-None-Match"] = self._appliances_etag
             async with aiohttp.ClientSession() as session:
-                async with session.get('https://api.github.com/repos/GNS3/gns3-registry/contents/appliances', headers=headers) as response:
+                async with session.get(
+                        'https://api.github.com/repos/GNS3/gns3-registry/contents/appliances',
+                        headers=headers
+                ) as response:
                     if response.status == 304:
                         log.info("Appliances are already up-to-date (ETag {})".format(self._appliances_etag))
                         return
@@ -220,7 +216,7 @@ class ApplianceManager:
                         from . import Controller
                         Controller.instance().save()
                     json_data = await response.json()
-                appliances_dir = self._builtin_appliances_path()
+                appliances_dir = self.builtin_appliances_path()
                 downloaded_appliance_files = []
                 for appliance in json_data:
                     if appliance["type"] == "file":
