@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import ipaddress
 import aiohttp
 import asyncio
 import html
@@ -25,8 +26,8 @@ import os
 from .compute import ComputeConflict, ComputeError
 from .ports.port_factory import PortFactory, StandardPortFactory, DynamipsPortFactory
 from ..utils.images import images_directories
+from ..utils import macaddress_to_int, int_to_macaddress
 from ..config import Config
-from ..utils.qt import qt_font_to_style
 
 
 import logging
@@ -484,7 +485,7 @@ class Node:
 
         # None properties are not be send. Because it can mean the emulator doesn't support it
         for key in list(data.keys()):
-            if data[key] is None or data[key] is {} or key in self.CONTROLLER_ONLY_PROPERTIES:
+            if data[key] is None or data[key] == {} or key in self.CONTROLLER_ONLY_PROPERTIES:
                 del data[key]
 
         return data
@@ -662,7 +663,13 @@ class Node:
                         break
                 port_name = "eth{}".format(adapter_number)
                 port_name = custom_adapter_settings.get("port_name", port_name)
-                self._ports.append(PortFactory(port_name, 0, adapter_number, 0, "ethernet", short_name=port_name))
+                mac_address = custom_adapter_settings.get("mac_address")
+                if not mac_address and "mac_address" in self._properties:
+                    mac_address = int_to_macaddress(macaddress_to_int(self._properties["mac_address"]) + adapter_number)
+
+                port = PortFactory(port_name, 0, adapter_number, 0, "ethernet", short_name=port_name)
+                port.mac_address = mac_address
+                self._ports.append(port)
         elif self._node_type in ("ethernet_switch", "ethernet_hub"):
             # Basic node we don't want to have adapter number
             port_number = 0
@@ -716,6 +723,17 @@ class Node:
                 "first_port_name": self._first_port_name,
                 "custom_adapters": self._custom_adapters
             }
+
+        # add brackets around console host for http/https console type
+        console_host = str(self._compute.console_host)
+        if self._console_type == "http" or self._console_type == "https":
+            try:
+                ip = ipaddress.ip_address(console_host)
+                if isinstance(ip, ipaddress.IPv6Address):
+                        console_host = '[' + console_host + ']'
+            except ValueError:
+                pass
+
         return {
             "compute_id": str(self._compute.id),
             "project_id": self._project.id,
@@ -725,7 +743,7 @@ class Node:
             "node_directory": self._node_directory,
             "name": self._name,
             "console": self._console,
-            "console_host": str(self._compute.console_host),
+            "console_host": console_host,
             "console_type": self._console_type,
             "console_auto_start": self._console_auto_start,
             "command_line": self._command_line,
