@@ -317,7 +317,7 @@ class DockerHandler:
         props = [
             "name", "console", "aux", "console_type", "console_resolution",
             "console_http_port", "console_http_path", "start_command",
-            "environment", "adapters", "extra_hosts", "extra_volumes"
+            "environment", "adapters", "mac_address", "custom_adapters", "extra_hosts", "extra_volumes"
         ]
 
         changed = False
@@ -425,3 +425,23 @@ class DockerHandler:
         docker_manager = Docker.instance()
         container = docker_manager.get_node(request.match_info["node_id"], project_id=request.match_info["project_id"])
         return await container.start_websocket_console(request)
+
+    @Route.post(
+        r"/projects/{project_id}/docker/nodes/{node_id}/console/reset",
+        description="Reset console",
+        parameters={
+            "project_id": "Project UUID",
+            "node_id": "Node UUID",
+        },
+        status_codes={
+            204: "Console has been reset",
+            400: "Invalid request",
+            404: "Instance doesn't exist",
+            409: "Container not started"
+        })
+    async def reset_console(request, response):
+
+        docker_manager = Docker.instance()
+        container = docker_manager.get_node(request.match_info["node_id"], project_id=request.match_info["project_id"])
+        await container.reset_console()
+        response.set_status(204)
