@@ -29,7 +29,7 @@ from tests.utils import asyncio_patch, AsyncioMagicMock
 
 
 @pytest.fixture
-async def manager(loop, port_manager):
+async def manager(port_manager):
 
     m = Dynamips.instance()
     m.port_manager = port_manager
