@@ -47,15 +47,19 @@ async def node(controller, project):
 
 async def test_affect_uuid():
 
-    p = Project(name="Test")
-    assert len(p.id) == 36
-    p = Project(project_id='00010203-0405-0607-0809-0a0b0c0d0e0f', name="Test 2")
-    assert p.id == '00010203-0405-0607-0809-0a0b0c0d0e0f'
+    with patch('gns3server.controller.project.Project.emit_controller_notification') as mock_notification:
+        p = Project(name="Test")
+        mock_notification.assert_called()
+        assert len(p.id) == 36
+        p = Project(project_id='00010203-0405-0607-0809-0a0b0c0d0e0f', name="Test 2")
+        assert p.id == '00010203-0405-0607-0809-0a0b0c0d0e0f'
 
 
 async def test_json():
 
-    p = Project(name="Test")
+    with patch('gns3server.controller.project.Project.emit_controller_notification') as mock_notification:
+        p = Project(name="Test")
+        mock_notification.assert_called()
 
     assert p.__json__() == {
         "name": "Test",
@@ -83,11 +87,11 @@ async def test_json():
 async def test_update(controller):
 
     project = Project(controller=controller, name="Hello")
-    project.emit_notification = MagicMock()
+    project.emit_controller_notification = MagicMock()
     assert project.name == "Hello"
     await project.update(name="World")
     assert project.name == "World"
-    project.emit_notification.assert_any_call("project.updated", project.__json__())
+    project.emit_controller_notification.assert_any_call("project.updated", project.__json__())
 
 
 async def test_update_on_compute(controller):
@@ -106,7 +110,9 @@ async def test_path(projects_dir):
 
     directory = projects_dir
     with patch("gns3server.utils.path.get_default_project_directory", return_value=directory):
-        p = Project(project_id=str(uuid4()), name="Test")
+        with patch('gns3server.controller.project.Project.emit_controller_notification') as mock_notification:
+            p = Project(project_id=str(uuid4()), name="Test")
+            mock_notification.assert_called()
         assert p.path == os.path.join(directory, p.id)
         assert os.path.exists(os.path.join(directory, p.id))
 
@@ -124,23 +130,27 @@ def test_path_exist(tmpdir):
 
 async def test_init_path(tmpdir):
 
-    p = Project(path=str(tmpdir), project_id=str(uuid4()), name="Test")
-    assert p.path == str(tmpdir)
+    with patch('gns3server.controller.project.Project.emit_controller_notification') as mock_notification:
+        p = Project(path=str(tmpdir), project_id=str(uuid4()), name="Test")
+        mock_notification.assert_called()
+        assert p.path == str(tmpdir)
 
 
 @pytest.mark.skipif(sys.platform.startswith("win"), reason="Not supported on Windows")
 async def test_changing_path_with_quote_not_allowed(tmpdir):
 
     with pytest.raises(aiohttp.web.HTTPForbidden):
-        p = Project(project_id=str(uuid4()), name="Test")
-        p.path = str(tmpdir / "project\"53")
+        with patch('gns3server.controller.project.Project.emit_controller_notification'):
+            p = Project(project_id=str(uuid4()), name="Test")
+            p.path = str(tmpdir / "project\"53")
 
 
 async def test_captures_directory(tmpdir):
 
-    p = Project(path=str(tmpdir / "capturestest"), name="Test")
-    assert p.captures_directory == str(tmpdir / "capturestest" / "project-files" / "captures")
-    assert os.path.exists(p.captures_directory)
+    with patch('gns3server.controller.project.Project.emit_controller_notification'):
+        p = Project(path=str(tmpdir / "capturestest"), name="Test")
+        assert p.captures_directory == str(tmpdir / "capturestest" / "project-files" / "captures")
+        assert os.path.exists(p.captures_directory)
 
 
 async def test_add_node_local(controller):
@@ -649,36 +659,39 @@ async def test_dump(projects_dir):
 
     directory = projects_dir
     with patch("gns3server.utils.path.get_default_project_directory", return_value=directory):
-        p = Project(project_id='00010203-0405-0607-0809-0a0b0c0d0e0f', name="Test")
-        p.dump()
-        with open(os.path.join(directory, p.id, "Test.gns3")) as f:
-            content = f.read()
-            assert "00010203-0405-0607-0809-0a0b0c0d0e0f" in content
+        with patch('gns3server.controller.project.Project.emit_controller_notification'):
+            p = Project(project_id='00010203-0405-0607-0809-0a0b0c0d0e0f', name="Test")
+            p.dump()
+            with open(os.path.join(directory, p.id, "Test.gns3")) as f:
+                content = f.read()
+                assert "00010203-0405-0607-0809-0a0b0c0d0e0f" in content
 
 
 async def test_open_close(controller):
 
-    project = Project(controller=controller, name="Test")
-    assert project.status == "opened"
-    await project.close()
-    project.start_all = AsyncioMagicMock()
-    await project.open()
-    assert not project.start_all.called
-    assert project.status == "opened"
-    project.emit_notification = MagicMock()
-    await project.close()
-    assert project.status == "closed"
-    project.emit_notification.assert_any_call("project.closed", project.__json__())
+    with patch('gns3server.controller.project.Project.emit_controller_notification'):
+        project = Project(controller=controller, name="Test")
+        assert project.status == "opened"
+        await project.close()
+        project.start_all = AsyncioMagicMock()
+        await project.open()
+        assert not project.start_all.called
+        assert project.status == "opened"
+        project.emit_controller_notification = MagicMock()
+        await project.close()
+        assert project.status == "closed"
+        project.emit_controller_notification.assert_any_call("project.closed", project.__json__())
 
 
 async def test_open_auto_start(controller):
 
-    project = Project(controller=controller, name="Test", auto_start=True)
-    assert project.status == "opened"
-    await project.close()
-    project.start_all = AsyncioMagicMock()
-    await project.open()
-    assert project.start_all.called
+    with patch('gns3server.controller.project.Project.emit_controller_notification'):
+        project = Project(controller=controller, name="Test", auto_start=True)
+        assert project.status == "opened"
+        await project.close()
+        project.start_all = AsyncioMagicMock()
+        await project.open()
+        assert project.start_all.called
 
 
 def test_is_running(project, node):
@@ -737,7 +750,7 @@ def test_snapshots(project):
 def test_get_snapshot(project):
 
     os.makedirs(os.path.join(project.path, "snapshots"))
-    open(os.path.join(project.path, "snapshots", "test1.gns3project"), "w+").close()
+    open(os.path.join(project.path, "snapshots", "test1_260716_103713.gns3project"), "w+").close()
     project.reset()
 
     snapshot = list(project.snapshots.values())[0]
